#setup the countries tool only for SE Asia
SE_ASIA_COUNTRIES=True

#languages to support by default
LANGUAGES = ['en','id','ms-my']

#Names of the folders inside the taxonomy hierarchy
TOPLEVEL_TAXONOMY_FOLDER='taxonomy'
GENRE_FOLDER='genre'
CATEGORIES_FOLDER='topic'
COUNTRIES_FOLDER='countries'
SUBMISSIONS_FOLDER='callouts'
